A Limerick
##########

:date: 2011-06-13 01:00
:category: Alt
:featured: True


::

    There was an old man from Nantucket
    Who kept all his cash in a bucket,
    His daughter, called Nan, ran away with a man,
    And as for the bucket - Nantucket!

